abacusai.model_monitor — AbacusAI documentation

# `abacusai.model_monitor`

## Module Contents

### Classes

`ModelMonitor` | A model monitor

class abacusai.model_monitor.ModelMonitor(client, modelMonitorId=None, name=None, createdAt=None, projectId=None, trainingFeatureGroupId=None, predictionFeatureGroupId=None, alertConfig=None, refreshSchedules={}, latestMonitorModelVersion={})

  Bases: `abacusai.return_class.AbstractApiClass`

  A model monitor

  Parameters

    - client (ApiClient) – An authenticated API Client instance

    - modelMonitorId (str) – The unique identifier of the model monitor.

    - name (str) – The user-friendly name for the model.

    - createdAt (str) – Date and time at which the model was created.

    - projectId (str) – The project this model belongs to.

    - trainingFeatureGroupId (unique string identifiers) – Feature group IDs that this model monitor is monitoring.

    - predictionFeatureGroupId (unique string identifiers) – Feature group IDs that this model monitor is monitoring.

    - alertConfig (dict) – Alerting configuration for this model monitor.

    - latestMonitorModelVersion (ModelMonitorVersion) – The latest model monitor version.

    - refreshSchedules (RefreshSchedule) – List of refresh schedules that indicate when the next model version will be trained.

  __repr__(self)

    Return repr(self).

  to_dict(self)

    Get a dict representation of the parameters in this class

    Returns

      The dict value representation of the class parameters

    Return type

      dict

  rerun(self)

    Reruns the specified model monitor.

    Parameters

      model_monitor_id (str) – The model monitor to rerun.

    Returns

      The model monitor that is being rerun.

    Return type

      ModelMonitor

  refresh(self)

    Calls describe and refreshes the current object’s fields

    Returns

      The current object

    Return type

      ModelMonitor

  describe(self)

    Retrieves a full description of the specified model monitor.

    Parameters

      model_monitor_id (str) – The unique ID associated with the model monitor.

    Returns

      The description of the model monitor.

    Return type

      ModelMonitor

  list_versions(self, limit=100, start_after_version=None)

    Retrieves a list of the versions for a given model monitor.

    Parameters

      - limit (int) – The max length of the list of all model monitor versions.

      - start_after_version (str) – The id of the version after which the list starts.

    Returns

      An array of model monitor versions.

    Return type

      ModelMonitorVersion

  rename(self, name)

    Renames a model monitor

    Parameters

      name (str) – The name to apply to the model monitor

  delete(self)

    Deletes the specified model monitor and all its versions.

    Parameters

      model_monitor_id (str) – The ID of the model monitor to delete.